@@ -83,16 +83,10 @@ Interface::OpenStatus InterfacePrivate::loadDeviceOptions()
     SANE_Status status;
     SANE_Word numSaneOptions;
     SANE_Int res;
-    // update the device list if needed to get the vendor and model info
-    if (m_findDevThread->devicesList().size() == 0) {
-        m_findDevThread->start();
-    } else {
+    // try to fill the device model and vendor field
+    if (m_findDevThread->devicesList().size() != 0) {
         // use the "old" existing list
         devicesListUpdated();
-        // if m_vendor is not updated it means that the list needs to be updated.
-        if (m_vendor.isEmpty()) {
-            m_findDevThread->start();
-        }
     }
 
     // Read the options (start with option 0 the number of parameters)
